@@ -679,6 +679,21 @@ class VariableClUpdateOtherSet(Variable):
         return self.value
 
 
+class VariableClUpdateOtherGitExists(Variable):
+    """
+    Проверка, существует ли папка .git в профиле контейнера
+    """
+    type = 'bool'
+    repos_path = 'cl_update_repos_storage'
+
+    def get(self):
+        rep = f"{self.Get(self.repos_path)}/container"
+        if os.path.exists(os.path.join(rep, '.git')):
+            return True
+        return False
+
+
+
 class VariableClUpdateOtherRepData(ReadonlyTableVariable):
     """
     Информация о прочих репозиториях
